@@ -114,7 +114,15 @@ class s2py():
                 comments = []
                 x = ""
                 for i in data:
-                    x = i['content']
+                    if "content" in i:
+                        x = i['content']
+                    else:
+                        if "image" in i:
+                            x = i['image']
+                        else:
+                            x = "None"
+                        
+
                     comments.append(x)
                 data = json.dumps(comments)
                 return data
